BiblioPixel: the light programming system
------------------------------------------

`Documentation <https://maniacallabs.github.io/BiblioPixel>`_...
---------------------------------------------------------------------

.. code-block:: yaml

       animation: $bpa.matrix.bloom
       shape: [64, 64]


.. image:: https://raw.githubusercontent.com/ManiacalLabs/DocsFiles/master/BiblioPixel/README.gif
   :target: https://raw.githubusercontent.com/ManiacalLabs/DocsFiles/master/BiblioPixel/README.gif
   :alt: Result
